#-------------------------------------------------------------------------------
# Name:        latexMerger.py
# Purpose:     Merges several latex files that were seperated by \input to a
#              single file, including .bbl files
#
# Author:      schueller
#
# Created:     11.04.2012
# Copyright:   (c) Gereon Schueller, Bonn 2012
# Licence:     GPLv2
#-------------------------------------------------------------------------------
#!/usr/bin/env python

import sys
import getopt

def main():
    if len(sys.argv)<2:
        print("Please provide the name and path of the main .tex file!")
        sys.exit(255)

    #Separate path and filename
    x = sys.argv[1].rfind('\\') + 1
    in_path = sys.argv[1][:x]
    in_file_name = sys.argv[1][x:]

    #Begin Recursion
    print_subfile(in_path,in_file_name, in_file_name)

def print_subfile(in_path, in_file_name, main_file):
    in_file = open(in_path + in_file_name, "r")
    for line in in_file:
        origLine = line
        line=line.strip(' \t\n\r')
        if line.startswith('%'):
            sys.stdout.write(origLine) #comment
        else:
            if line.startswith('\\input{'): #input file
                arg_end = line.find('}')
                sub_file = line[:arg_end].replace('\input{','')
                if  not (sub_file.endswith('.tex') or sub_file.endswith('.bbl')):
                    sub_file = sub_file + ".tex"
                print_subfile(in_path, sub_file, main_file)
            else: #no input-line?
                if line.startswith('\\bibliography{'): #bibliography
                    print_subfile(in_path,main_file.replace('.tex','.bbl'), main_file)
                else: #normal line
                    sys.stdout.write(origLine)


if __name__ == '__main__':
    main()
